==> vesselapi-3.34.0.tar.gz: vesselapi-3.34.0/README.md <==
# Vessel API Python SDK

The Vessel API Python SDK is a PyPi library for accessing the Vessel API, a Unified CRM API that provides standardized endpoints for performing operations on common CRM Objects.

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install vesselapi
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import vesselapi
from vesselapi.models import operations

s = vesselapi.VesselAPI(
    security=shared.Security(
        vessel_api_token="",
    ),
)

req = operations.GetBatchCrmAccountRequest(
    access_token='corrupti',
    all_fields=False,
    ids='provident',
)

res = s.accounts.batch(req)

if res.response_body is not None:
    # handle response
```
<!-- End SDK Example Usage -->

## Authentication

To authenticate the Vessel Node SDK you will need to provide a Vessel API Token, along with an Access Token for each request. For more details please see the [Vessel API Documentation](https://docs.vessel.land/authentication-and-security).

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [accounts](docs/sdks/accounts/README.md)

* [batch](docs/sdks/accounts/README.md#batch) - Get Batch Accounts
* [create](docs/sdks/accounts/README.md#create) - Create Account
* [details](docs/sdks/accounts/README.md#details) - Get Account Details
* [find](docs/sdks/accounts/README.md#find) - Get Account
* [list](docs/sdks/accounts/README.md#list) - Get All Accounts
* [search](docs/sdks/accounts/README.md#search) - Search Accounts
* [update](docs/sdks/accounts/README.md#update) - Update Account

### [attendees](docs/sdks/attendees/README.md)

* [batch](docs/sdks/attendees/README.md#batch) - Get Batch Event Attendees
* [create](docs/sdks/attendees/README.md#create) - Create Event Attendee
* [details](docs/sdks/attendees/README.md#details) - Get Event Attendee Details
* [find](docs/sdks/attendees/README.md#find) - Get Event Attendee
* [list](docs/sdks/attendees/README.md#list) - Get All Event Attendees
* [search](docs/sdks/attendees/README.md#search) - Search Event Attendees
* [update](docs/sdks/attendees/README.md#update) - Update Event Attendee

### [calls](docs/sdks/calls/README.md)

* [batch](docs/sdks/calls/README.md#batch) - Batch Calls
* [create](docs/sdks/calls/README.md#create) - Create Call
* [details](docs/sdks/calls/README.md#details) - Get Call Details
* [find](docs/sdks/calls/README.md#find) - Get Call
* [list](docs/sdks/calls/README.md#list) - Get All Calls
* [search](docs/sdks/calls/README.md#search) - Search Calls
* [update](docs/sdks/calls/README.md#update) - Update Call

### [connections](docs/sdks/connections/README.md)

* [delete](docs/sdks/connections/README.md#delete) - Delete Connection
* [find](docs/sdks/connections/README.md#find) - Get Connection
* [list](docs/sdks/connections/README.md#list) - Get All Connections

### [contacts](docs/sdks/contacts/README.md)

* [batch](docs/sdks/contacts/README.md#batch) - Get Batch Contacts
* [create](docs/sdks/contacts/README.md#create) - Create Contact
* [details](docs/sdks/contacts/README.md#details) - Get Contact Details
* [find](docs/sdks/contacts/README.md#find) - Get Contact
* [list](docs/sdks/contacts/README.md#list) - Get All Contacts
* [search](docs/sdks/contacts/README.md#search) - Search Contacts
* [update](docs/sdks/contacts/README.md#update) - Update Contact

### [deals](docs/sdks/deals/README.md)

* [batch](docs/sdks/deals/README.md#batch) - Get Batch Deals
* [create](docs/sdks/deals/README.md#create) - Create Deal
* [details](docs/sdks/deals/README.md#details) - Get Deal Details
* [find](docs/sdks/deals/README.md#find) - Get Deal
* [list](docs/sdks/deals/README.md#list) - Get All Deals
* [search](docs/sdks/deals/README.md#search) - Search Deals
* [update](docs/sdks/deals/README.md#update) - Update Deal

### [emails](docs/sdks/emails/README.md)

* [batch](docs/sdks/emails/README.md#batch) - Get Batch Emails
* [create](docs/sdks/emails/README.md#create) - Create Email
* [details](docs/sdks/emails/README.md#details) - Get Email Details
* [find](docs/sdks/emails/README.md#find) - Get Email
* [list](docs/sdks/emails/README.md#list) - Get All Emails
* [search](docs/sdks/emails/README.md#search) - Search Emails
* [update](docs/sdks/emails/README.md#update) - Update Email

### [events](docs/sdks/events/README.md)

* [batch](docs/sdks/events/README.md#batch) - Get Batch Events
* [create](docs/sdks/events/README.md#create) - Create Event
* [details](docs/sdks/events/README.md#details) - Get Event Details
* [find](docs/sdks/events/README.md#find) - Get Event
* [list](docs/sdks/events/README.md#list) - Get All Events
* [search](docs/sdks/events/README.md#search) - Search Events
* [update](docs/sdks/events/README.md#update) - Update Event

### [integrations](docs/sdks/integrations/README.md)

* [list](docs/sdks/integrations/README.md#list) - Get CRM Integrations

### [leads](docs/sdks/leads/README.md)

* [batch](docs/sdks/leads/README.md#batch) - Get Batch Leads
* [create](docs/sdks/leads/README.md#create) - Create Lead
* [details](docs/sdks/leads/README.md#details) - Get Lead Details
* [find](docs/sdks/leads/README.md#find) - Get Lead
* [list](docs/sdks/leads/README.md#list) - Get All Leads
* [search](docs/sdks/leads/README.md#search) - Search Leads
* [update](docs/sdks/leads/README.md#update) - Update Lead

### [links](docs/sdks/links/README.md)

* [create](docs/sdks/links/README.md#create) - Exchange Public Token for Access Token

### [notes](docs/sdks/notes/README.md)

* [batch](docs/sdks/notes/README.md#batch) - Get Batch Notes
* [create](docs/sdks/notes/README.md#create) - Create Note
* [details](docs/sdks/notes/README.md#details) - Get Note Details
* [find](docs/sdks/notes/README.md#find) - Get Note
* [list](docs/sdks/notes/README.md#list) - Get All Notes
* [search](docs/sdks/notes/README.md#search) - Search Notes
* [update](docs/sdks/notes/README.md#update) - Update Note

### [passthrough](docs/sdks/passthrough/README.md)

* [create](docs/sdks/passthrough/README.md#create) - Passthrough Request

### [tasks](docs/sdks/tasks/README.md)

* [batch](docs/sdks/tasks/README.md#batch) - Get Batch Tasks
* [create](docs/sdks/tasks/README.md#create) - Create Task
* [details](docs/sdks/tasks/README.md#details) - Get Task Details
* [find](docs/sdks/tasks/README.md#find) - Get Task
* [list](docs/sdks/tasks/README.md#list) - Get All Tasks
* [search](docs/sdks/tasks/README.md#search) - Search Tasks
* [update](docs/sdks/tasks/README.md#update) - Update Task

### [tokens](docs/sdks/tokens/README.md)

* [create](docs/sdks/tokens/README.md#create) - Create Link Token

### [users](docs/sdks/users/README.md)

* [batch](docs/sdks/users/README.md#batch) - Get Batch Users
* [details](docs/sdks/users/README.md#details) - Get User Details
* [find](docs/sdks/users/README.md#find) - Get User
* [list](docs/sdks/users/README.md#list) - Get All Users
* [search](docs/sdks/users/README.md#search) - Search Users

### [webhooks](docs/sdks/webhooks/README.md)

* [create](docs/sdks/webhooks/README.md#create) - Create Webhook
* [delete](docs/sdks/webhooks/README.md#delete) - Remove Webhook
* [find](docs/sdks/webhooks/README.md#find) - Get Webhook
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)

==> vesselapi-3.47.0.tar.gz: vesselapi-3.47.0/README.md <==
# Vessel API Python SDK

The Vessel API Python SDK is a PyPi library for accessing the Vessel API, a Unified CRM API that provides standardized endpoints for performing operations on common CRM Objects.

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install vesselapi
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->


```python
import vesselapi
from vesselapi.models import operations, shared

s = vesselapi.VesselAPI(
    security=shared.Security(
        vessel_api_token="",
    ),
)

req = operations.GetBatchCrmAccountRequest(
    access_token='corrupti',
    all_fields=False,
    ids='provident',
)

res = s.accounts.batch(req)

if res.response_body is not None:
    # handle response
```
<!-- End SDK Example Usage -->

## Authentication

To authenticate the Vessel Node SDK you will need to provide a Vessel API Token, along with an Access Token for each request. For more details please see the [Vessel API Documentation](https://docs.vessel.land/authentication-and-security).

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [accounts](docs/sdks/accounts/README.md)

* [batch](docs/sdks/accounts/README.md#batch) - Get Batch Accounts
* [create](docs/sdks/accounts/README.md#create) - Create Account
* [details](docs/sdks/accounts/README.md#details) - Get Account Details
* [find](docs/sdks/accounts/README.md#find) - Get Account
* [list](docs/sdks/accounts/README.md#list) - Get All Accounts
* [search](docs/sdks/accounts/README.md#search) - Search Accounts
* [update](docs/sdks/accounts/README.md#update) - Update Account

### [attendees](docs/sdks/attendees/README.md)

* [batch](docs/sdks/attendees/README.md#batch) - Get Batch Event Attendees
* [create](docs/sdks/attendees/README.md#create) - Create Event Attendee
* [details](docs/sdks/attendees/README.md#details) - Get Event Attendee Details
* [find](docs/sdks/attendees/README.md#find) - Get Event Attendee
* [list](docs/sdks/attendees/README.md#list) - Get All Event Attendees
* [search](docs/sdks/attendees/README.md#search) - Search Event Attendees
* [update](docs/sdks/attendees/README.md#update) - Update Event Attendee

### [calls](docs/sdks/calls/README.md)

* [batch](docs/sdks/calls/README.md#batch) - Batch Calls
* [create](docs/sdks/calls/README.md#create) - Create Call
* [details](docs/sdks/calls/README.md#details) - Get Call Details
* [find](docs/sdks/calls/README.md#find) - Get Call
* [list](docs/sdks/calls/README.md#list) - Get All Calls
* [search](docs/sdks/calls/README.md#search) - Search Calls
* [update](docs/sdks/calls/README.md#update) - Update Call

### [connections](docs/sdks/connections/README.md)

* [delete](docs/sdks/connections/README.md#delete) - Delete Connection
* [find](docs/sdks/connections/README.md#find) - Get Connection
* [list](docs/sdks/connections/README.md#list) - Get All Connections

### [contacts](docs/sdks/contacts/README.md)

* [batch](docs/sdks/contacts/README.md#batch) - Get Batch Contacts
* [create](docs/sdks/contacts/README.md#create) - Create Contact
* [details](docs/sdks/contacts/README.md#details) - Get Contact Details
* [find](docs/sdks/contacts/README.md#find) - Get Contact
* [list](docs/sdks/contacts/README.md#list) - Get All Contacts
* [search](docs/sdks/contacts/README.md#search) - Search Contacts
* [update](docs/sdks/contacts/README.md#update) - Update Contact

### [deals](docs/sdks/deals/README.md)

* [batch](docs/sdks/deals/README.md#batch) - Get Batch Deals
* [create](docs/sdks/deals/README.md#create) - Create Deal
* [details](docs/sdks/deals/README.md#details) - Get Deal Details
* [find](docs/sdks/deals/README.md#find) - Get Deal
* [list](docs/sdks/deals/README.md#list) - Get All Deals
* [search](docs/sdks/deals/README.md#search) - Search Deals
* [update](docs/sdks/deals/README.md#update) - Update Deal

### [emails](docs/sdks/emails/README.md)

* [batch](docs/sdks/emails/README.md#batch) - Get Batch Emails
* [create](docs/sdks/emails/README.md#create) - Create Email
* [details](docs/sdks/emails/README.md#details) - Get Email Details
* [find](docs/sdks/emails/README.md#find) - Get Email
* [list](docs/sdks/emails/README.md#list) - Get All Emails
* [search](docs/sdks/emails/README.md#search) - Search Emails
* [update](docs/sdks/emails/README.md#update) - Update Email

### [events](docs/sdks/events/README.md)

* [batch](docs/sdks/events/README.md#batch) - Get Batch Events
* [create](docs/sdks/events/README.md#create) - Create Event
* [details](docs/sdks/events/README.md#details) - Get Event Details
* [find](docs/sdks/events/README.md#find) - Get Event
* [list](docs/sdks/events/README.md#list) - Get All Events
* [search](docs/sdks/events/README.md#search) - Search Events
* [update](docs/sdks/events/README.md#update) - Update Event

### [integrations](docs/sdks/integrations/README.md)

* [list](docs/sdks/integrations/README.md#list) - Get CRM Integrations

### [leads](docs/sdks/leads/README.md)

* [batch](docs/sdks/leads/README.md#batch) - Get Batch Leads
* [create](docs/sdks/leads/README.md#create) - Create Lead
* [details](docs/sdks/leads/README.md#details) - Get Lead Details
* [find](docs/sdks/leads/README.md#find) - Get Lead
* [list](docs/sdks/leads/README.md#list) - Get All Leads
* [search](docs/sdks/leads/README.md#search) - Search Leads
* [update](docs/sdks/leads/README.md#update) - Update Lead

### [links](docs/sdks/links/README.md)

* [create](docs/sdks/links/README.md#create) - Exchange Public Token for Access Token

### [notes](docs/sdks/notes/README.md)

* [batch](docs/sdks/notes/README.md#batch) - Get Batch Notes
* [create](docs/sdks/notes/README.md#create) - Create Note
* [details](docs/sdks/notes/README.md#details) - Get Note Details
* [find](docs/sdks/notes/README.md#find) - Get Note
* [list](docs/sdks/notes/README.md#list) - Get All Notes
* [search](docs/sdks/notes/README.md#search) - Search Notes
* [update](docs/sdks/notes/README.md#update) - Update Note

### [passthrough](docs/sdks/passthrough/README.md)

* [create](docs/sdks/passthrough/README.md#create) - Passthrough Request

### [tasks](docs/sdks/tasks/README.md)

* [batch](docs/sdks/tasks/README.md#batch) - Get Batch Tasks
* [create](docs/sdks/tasks/README.md#create) - Create Task
* [details](docs/sdks/tasks/README.md#details) - Get Task Details
* [find](docs/sdks/tasks/README.md#find) - Get Task
* [list](docs/sdks/tasks/README.md#list) - Get All Tasks
* [search](docs/sdks/tasks/README.md#search) - Search Tasks
* [update](docs/sdks/tasks/README.md#update) - Update Task

### [tokens](docs/sdks/tokens/README.md)

* [create](docs/sdks/tokens/README.md#create) - Create Link Token

### [users](docs/sdks/users/README.md)

* [batch](docs/sdks/users/README.md#batch) - Get Batch Users
* [details](docs/sdks/users/README.md#details) - Get User Details
* [find](docs/sdks/users/README.md#find) - Get User
* [list](docs/sdks/users/README.md#list) - Get All Users
* [search](docs/sdks/users/README.md#search) - Search Users

### [webhooks](docs/sdks/webhooks/README.md)

* [create](docs/sdks/webhooks/README.md#create) - Create Webhook
* [delete](docs/sdks/webhooks/README.md#delete) - Remove Webhook
* [find](docs/sdks/webhooks/README.md#find) - Get Webhook
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
